
USE codepot;

CREATE TABLE site (
	id          VARCHAR(32)  PRIMARY KEY,
	name        VARCHAR(128) NOT NULL,
	text        TEXT         NOT NULL,

	createdon   DATETIME,
	updatedon   DATETIME,
	createdby   VARCHAR(32),
	updatedby   VARCHAR(32)
) charset=utf8 engine=InnoDB;

CREATE TABLE project (
	id          VARCHAR(32)  PRIMARY KEY,
	name        VARCHAR(255) UNIQUE NOT NULL,
	summary     VARCHAR(255) NOT NULL,
	description TEXT NOT NULL,

	createdon   DATETIME,
	updatedon   DATETIME,
	createdby   VARCHAR(32),
	updatedby   VARCHAR(32)

) charset=utf8 engine=InnoDB;

CREATE TABLE project_membership (
	projectid VARCHAR(32) NOT NULL,
	userid    VARCHAR(32) NOT NULL,
	priority  INTEGER     NOT NULL,
	UNIQUE KEY membership (projectid, userid),
	CONSTRAINT membership_projectid FOREIGN KEY (projectid) REFERENCES project(id) 
		ON DELETE CASCADE ON UPDATE CASCADE
) charset=utf8 engine=InnoDB;

CREATE TABLE wiki (
	projectid  VARCHAR(32)   NOT NULL,
	name       VARCHAR(255)  NOT NULL,
	text	   TEXT          NOT NULL,

	createdon  DATETIME,
	updatedon  DATETIME,
	createdby  VARCHAR(32),
	updatedby  VARCHAR(32),

	UNIQUE KEY wiki_id (projectid, name),

	CONSTRAINT wiki_projectid FOREIGN KEY (projectid) REFERENCES project(id)
		ON DELETE RESTRICT ON UPDATE CASCADE
) charset=utf8 engine=InnoDB;	

CREATE TABLE wiki_attachment (
	projectid  VARCHAR(32)   NOT NULL,
	wikiname   VARCHAR(255)  NOT NULL,
	name       VARCHAR(255)  NOT NULL,
	encname    VARCHAR(255)  NOT NULL,

	createdon  DATETIME,
	createdby  VARCHAR(32),

	UNIQUE KEY wiki_attachment_id (projectid, wikiname, name),

	CONSTRAINT wiki_attachment_projectid FOREIGN KEY (projectid) REFERENCES project(id)
		ON DELETE RESTRICT ON UPDATE CASCADE,

	CONSTRAINT wiki_attachment_wikiid FOREIGN KEY (projectid,wikiname) REFERENCES wiki(projectid,name)
		ON DELETE RESTRICT ON UPDATE CASCADE
) charset=utf8 engine=InnoDB;	

CREATE TABLE issue (
	projectid     VARCHAR(32)   NOT NULL,
	id            BIGINT        NOT NULL,
	summary       VARCHAR(255)  NOT NULL,
	description   TEXT          NOT NULL,

	type          VARCHAR(32)   NOT NULL,
	status        VARCHAR(32)   NOT NULL,
	owner         VARCHAR(255)  NOT NULL,
	priority      VARCHAR(32)   NOT NULL,

	createdon  DATETIME,
	updatedon  DATETIME,
	createdby  VARCHAR(32),
	updatedby  VARCHAR(32),

	PRIMARY KEY (projectid, id),
	KEY issue_status_type_summary (projectid, status, type, summary),
	KEY issue_summary (projectid, summary),

	CONSTRAINT issue_projectid FOREIGN KEY (projectid) REFERENCES project(id)
		ON DELETE RESTRICT ON UPDATE CASCADE
) charset=utf8 engine=InnoDB;	

CREATE TABLE issue_change (
	projectid VARCHAR(32)  NOT NULL,
	id        BIGINT       NOT NULL,
	sno       BIGINT       NOT NULL,
	
	type      VARCHAR(32)  NOT NULL,
	status    VARCHAR(32)  NOT NULL,
	owner     VARCHAR(255) NOT NULL,
	priority  VARCHAR(32)  NOT NULL,
	comment   TEXT         NOT NULL,

	updatedon DATETIME,
	updatedby VARCHAR(32),

	PRIMARY KEY (projectid, id, sno),
	KEY issue_update_time (projectid, id, updatedon),

	CONSTRAINT issue_update_id FOREIGN KEY (projectid,id) REFERENCES issue(projectid,id)
		ON DELETE RESTRICT ON UPDATE CASCADE

) charset=utf8 engine=InnoDB;

CREATE TABLE file (
	projectid   VARCHAR(32)   NOT NULL,
	name        VARCHAR(255)  NOT NULL,
	encname     VARCHAR(255)  NOT NULL,
	tag         VARCHAR(54)   NOT NULL,
	summary     VARCHAR(255)  NOT NULL,
	md5sum      CHAR(32)      NOT NULL,
	description TEXT          NOT NULL,

	createdon  DATETIME,
	updatedon  DATETIME, 
	createdby  VARCHAR(32),
	updatedby  VARCHAR(32),

	UNIQUE KEY file_id (projectid, name),
	UNIQUE KEY (encname),
	INDEX tagged_file_id (projectid, tag, name),

	CONSTRAINT file_projectid FOREIGN KEY (projectid) REFERENCES project(id) 
		ON DELETE RESTRICT ON UPDATE CASCADE
) charset=utf8 engine=InnoDB;	

CREATE TABLE log  (
	id         BIGINT PRIMARY KEY AUTO_INCREMENT,
	projectid  VARCHAR(32)  NOT NULL,
	type       VARCHAR(16)  NOT NULL,
	action     VARCHAR(16)  NOT NULL,
	userid     VARCHAR(32)  NOT NULL,
	message    TEXT         NOT NULL,
	createdon  DATETIME     NOT NULL,
	INDEX timed_project_type_action (createdon, projectid, type, action)
) charset=utf8 engine=InnoDB;	

CREATE TABLE user_settings (
	userid              VARCHAR(32) PRIMARY KEY,
	code_hide_line_num CHAR(1) NOT NULL,
	code_hide_details  CHAR(1) NOT NULL
) charset=utf8 engine=InnoDB;
